pub struct OperatorPlacement {
pub service_id: String,
pub window: bool,
pub partition: bool,
pub transforms_index: Option<usize>,
}Expand description
Describes where an operator is in a dataflow for add, edit, remove transforms index must be provided if window and partition are false
if window or partition is true, and transforms index is None, then the OperatorPlacement is referring to the assign_timestamp or assign_key operator respectively
if window and partition are true, the OperatorPlacement is referring to the partition inside the window
Fields
service_id: Stringwindow: boolpartition: booltransforms_index: Option<usize>Trait Implementations
Sourceimpl Clone for OperatorPlacement
impl Clone for OperatorPlacement
Sourcefn clone(&self) -> OperatorPlacement
fn clone(&self) -> OperatorPlacement
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OperatorPlacement
impl Debug for OperatorPlacement
Sourceimpl Default for OperatorPlacement
impl Default for OperatorPlacement
Sourcefn default() -> OperatorPlacement
fn default() -> OperatorPlacement
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for OperatorPlacement
impl<'de> Deserialize<'de> for OperatorPlacement
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for OperatorPlacement
impl PartialEq for OperatorPlacement
Sourceimpl Serialize for OperatorPlacement
impl Serialize for OperatorPlacement
impl Eq for OperatorPlacement
impl StructuralPartialEq for OperatorPlacement