pub struct Header {
pub name: String,
pub version: String,
pub namespace: String,
}Fields
name: Stringversion: Stringnamespace: StringImplementations
Sourceimpl Header
impl Header
Sourcepub fn from_pkg_name(pkg_name: &str) -> Result<Self>
pub fn from_pkg_name(pkg_name: &str) -> Result<Self>
extract header from package name which is in the format namespace/name@version
pub fn validate(&self) -> Result<(), Vec<HeaderValidationError>>
Sourcepub fn canonical_name(&self) -> String
pub fn canonical_name(&self) -> String
convert metadata to canonical name that can be used as file name